@@ -1,5 +1,6 @@
 from ..advisors import filt_block_advisor
 from .. import conf
+from ..advisors import AOP_COMMENT
 from ..utils import get_nice_str_list, layout_comment as layout
 
 DECORATOR_XPATH = (
@@ -11,7 +12,7 @@ DECORATOR_XPATH = (
 )
 
 @filt_block_advisor(xpath=DECORATOR_XPATH)
-def decorator_overview(block_dets, *, repeated_message=False):
+def decorator_overview(block_dets, *, repeat=False):
     """
     Look for decorators and explain some options for improving them.
     """
@@ -28,16 +29,16 @@ def decorator_overview(block_dets, *, repeated_message=False):
             if namespace:
                 name = f"{namespace}.{name}"
         decorator_names.append(name)
+
     dec_name_list = get_nice_str_list(decorator_names, quoter='`')
     plural = 's' if len(decorator_names) > 1 else ''
-    brief_msg = layout(f"""\
+    summary = layout(f"""\
             ### Decorator{plural} used
 
             The code uses the decorator{plural}: {dec_name_list}.
             """)
-    main_msg = brief_msg
-    if not repeated_message:
-        main_msg += (
+    if not repeat:
+        dec_dets = (
             layout("""\
 
                 Decorators are a common and handy feature of Python. Using them
@@ -95,8 +96,14 @@ def decorator_overview(block_dets, *, repeated_message=False):
                 say("sausage!")
                 ''', is_code=True)
         )
+        aop = AOP_COMMENT
+    else:
+        dec_dets = ''
+        aop = ''
+
     message = {
-        conf.BRIEF: brief_msg,
-        conf.MAIN: main_msg,
+        conf.BRIEF: summary,
+        conf.MAIN: summary + dec_dets,
+        conf.EXTRA: aop,
     }
     return message
