@@ -4,11 +4,6 @@ from ..utils import get_nice_str_list, int2nice, layout_comment as layout
 
 UNSPECIFIC_EXCEPTION = 'Exception'
 
-def _get_exception_block_comment(exception_block):
-    handlers = get_nice_str_list(exception_block, quoter='`')
-    comment = f"The following exception handlers were detected: {handlers}"
-    return comment
-
 def get_exception_blocks(blocks_dets):
     """
     There can be multiple try-except statements in a snippet so we have to
@@ -38,17 +33,26 @@ def exception_overview(blocks_dets):
     exception_blocks = get_exception_blocks(blocks_dets)
     if not exception_blocks:
         return None
-    brief_msg = '### Exception handling'
+
+    title = layout("""\
+
+        ### Exception handling
+
+        """)
+    block_comment_bits = []
     for n, exception_block in enumerate(exception_blocks, 1):
         counter = '' if len(exception_blocks) == 1 else f" {int2nice(n)}"
-        brief_msg += layout(f"""\
+        handlers = get_nice_str_list(exception_block, quoter='`')
+        block_comment_bits.append(layout(f"""\
 
             #### `try`-`except` block{counter}
 
-            """)
-        brief_msg += _get_exception_block_comment(exception_block)
+            The following exception handlers were detected: {handlers}
+            """))
+    block_comments = ''.join(block_comment_bits)
+
     message = {
-        conf.BRIEF: layout(brief_msg),
+        conf.BRIEF: title + block_comments,
     }
     return message
 
@@ -60,26 +64,22 @@ def unspecific_exception(blocks_dets):
     exception_blocks = get_exception_blocks(blocks_dets)
     if not exception_blocks:
         return None
-    brief_msg = ''
     unspecific_block_ns = []
-    has_title = False
-    has_unspecific = False
     for n, exception_block in enumerate(exception_blocks, 1):
         only_unspecific = (len(exception_block) == 1
             and exception_block[0] == UNSPECIFIC_EXCEPTION)
         if not only_unspecific:
             continue
-        has_unspecific = True
         unspecific_block_ns.append(n)
-        if not has_title:
-            brief_msg += layout("""\
-
-                #### Un-specific `Exception` only in `try`-`except` block(s)
-
-                """)
-        has_title = True
-    if not has_unspecific:
+    if not unspecific_block_ns:
         return None
+
+    title = layout("""\
+
+        #### Un-specific `Exception` only in `try`-`except` block(s)
+
+        """)
+
     n_unspecific = len(unspecific_block_ns)
     if n_unspecific == 1:
         block_n_specific_text = ' has'
@@ -89,7 +89,7 @@ def unspecific_exception(blocks_dets):
             for unspecific_block_n in unspecific_block_ns]
         blocks_ns = get_nice_str_list(unspecific_nice_block_ns, quoter='')
         block_n_specific_text = f"s {blocks_ns} have"
-    brief_msg += layout(f"""\
+    unspecific_warning = layout(f"""\
 
         `try`-`except` block{block_n_specific_text} an un-specific Exception
         only.
@@ -97,15 +97,14 @@ def unspecific_exception(blocks_dets):
         Using the un-specific exception type `Exception` is often completely
         appropriate. But if you are looking for specific exceptions you
         should handle those separately.
-
-        For example:
         """)
-    message = {
-        conf.BRIEF: layout(brief_msg),
-        conf.MAIN: (
-            layout(brief_msg)
-            +
-            layout("""\
+    unspecific_demo = (
+        layout(f"""\
+
+            For example:
+            """)
+        +
+        layout("""\
 
                 try:
                     spec_dicts[idx][spec_type]
@@ -117,6 +116,10 @@ def unspecific_exception(blocks_dets):
                 except Exception as e:
                     print(f"Unexpected exception - details: {e}")
                 """, is_code=True)
-        ),
+        )
+
+    message = {
+        conf.BRIEF: title + unspecific_warning,
+        conf.MAIN: title + unspecific_warning + unspecific_demo,
     }
     return message
