@@ -1,8 +1,7 @@
 from collections import defaultdict
 
-from ..advisors import any_block_advisor
+from ..advisors import any_block_advisor, is_reserved_name
 from .. import conf, utils
-from .shared import is_reserved_name
 from ..utils import get_nice_str_list, int2nice, layout_comment as layout
 
 def _get_shamed_names_title(reserved_names, bad_names, dubious_names):
@@ -48,15 +47,6 @@ def _get_shamed_names_title(reserved_names, bad_names, dubious_names):
                 title = 'Possibly some un-pythonic names'
     return title
 
-def _get_shamed_names_comment(shamed_names):
-    multiple_shamed_names = len(shamed_names) > 1
-    if multiple_shamed_names:
-        shamed_names_listed = utils.get_nice_str_list(shamed_names, quoter='`')
-        shamed_names_comment = f"{shamed_names_listed} are un-pythonic."
-    else:
-        shamed_names_comment = f"`{shamed_names[0]}` is un-pythonic."
-    return shamed_names_comment
-
 def get_standard_assigned_names(block_dets):
     """
     Only get names where we expect standard pythonic naming. So not named tuple
@@ -139,7 +129,7 @@ def get_all_names(block_dets, *, include_non_standard=False):
     return all_names
 
 @any_block_advisor(warning=True)
-def unpythonic_name_check(block_dets, *, repeated_message=False):
+def unpythonic_name_check(block_dets, *, repeat=False):
     """
     Check names used for use of reserved words and camel case.
     """
@@ -159,30 +149,39 @@ def unpythonic_name_check(block_dets, *, repeated_message=False):
             dubious_names.append(name)
     if not (reserved_names or bad_names or dubious_names):
         return None
-    title = _get_shamed_names_title(reserved_names, bad_names, dubious_names)
-    brief_msg = layout(f"""\
-        ### {title}
+
+    shamed_names_title = _get_shamed_names_title(
+        reserved_names, bad_names, dubious_names)
+    title = layout(f"""\
+
+        ### {shamed_names_title}
 
         """)
     if reserved_names:
         reserved_names_listed = utils.get_nice_str_list(
             reserved_names, quoter='`')
-        brief_msg += layout(f"""\
+        reserved_comment = layout(f"""\
             Reserved name(s): {reserved_names_listed}
             """)
+    else:
+        reserved_comment = ''
     if bad_names:
         bad_names_listed = utils.get_nice_str_list(bad_names, quoter='`')
-        brief_msg += layout(f"""\
+        bad_comment = layout(f"""\
             Un-pythonic name(s): {bad_names_listed}
             """)
+    else:
+        bad_comment = ''
     if dubious_names:
         dubious_names_listed = utils.get_nice_str_list(
             dubious_names, quoter='`')
-        brief_msg += layout(f"""\
+        dubious_comment = layout(f"""\
             Possibly un-pythonic name(s): {dubious_names_listed}
             """)
-    if not repeated_message:
-        brief_msg += layout("""\
+    else:
+        dubious_comment = ''
+    if not repeat:
+        snake_case = layout("""\
 
             Python variables should not named using reserved words e.g.
             `collections` or `sorted`.
@@ -191,9 +190,8 @@ def unpythonic_name_check(block_dets, *, repeated_message=False):
             lower case, with multiple words joined by underscores e.g.
             `high_scores` (not `highScores` or `HighScores`)
             """)
-    main_msg = brief_msg
-    if not repeated_message:
-        main_msg += layout("""\
+        pascal = layout("""\
+
             In Python class names and named tuples are expected to be in Pascal
             Case (also known as upper camel case) rather than the usual snake
             case. E.g. `collections.ChainMap`
@@ -202,14 +200,20 @@ def unpythonic_name_check(block_dets, *, repeated_message=False):
             with other code e.g. a library the Python is ported from, or the
             non-Python code that Python is wrapping.
             """)
+    else:
+        snake_case = ''
+        pascal = ''
+
     message = {
-        conf.BRIEF: brief_msg,
-        conf.MAIN: main_msg,
+        conf.BRIEF: (title + reserved_comment + bad_comment
+            + dubious_comment + snake_case + pascal),
+        conf.MAIN: (title + reserved_comment + bad_comment
+            + dubious_comment + snake_case + pascal),
     }
     return message
 
 @any_block_advisor(warning=True)
-def short_name_check(block_dets, *, repeated_message=False):
+def short_name_check(block_dets, *, repeat=False):
     """
     Check for short variable names.
     """
@@ -220,29 +224,36 @@ def short_name_check(block_dets, *, repeated_message=False):
             short_names[len(name)].add(name)
     if not short_names:
         return None
-    short_comment = ''
+
+    title = layout("""
+
+        ### Short variable name
+
+        """)
+    short_comment_bits = []
     for length, names in sorted(short_names.items()):
         freq = len(names)
         multiple = (freq > 1)
+        plural = 's' if length > 1 else ''
         if multiple:
             nice_list = get_nice_str_list(list(names), quoter='`')
-            short_comment += (
-                f" {int2nice(freq).title()} variables have names "
-                f"{int2nice(length)} characters long: {nice_list}.")
+            short_comment_bits.append((
+                f"{int2nice(freq)} variables have names "
+                f"{int2nice(length)} character{plural} long: {nice_list}."))
         else:
             name = names.pop()
-            short_comment += f"`{name}` is short."
-    brief_msg = layout(f"""\
-        ### Short variable names
+            short_comment_bits.append(f"`{name}` is short (only "
+                f"{int2nice(length)} character{plural} long).")
+    short_comment = '; '.join(short_comment_bits)
+    sometimes_ok = layout(f"""\
 
         Sometimes, short variable names are appropriate - even conventional -
         but they should be avoided outside of a few special cases. In your code:
 
         {short_comment}
         """)
-    main_msg = brief_msg
-    if not repeated_message:
-        main_msg += (
+    if not repeat:
+        idiomatic = (
             layout("""\
 
                 In many programming languages it is idiomatic to use `i`, `j`,
@@ -282,8 +293,11 @@ def short_name_check(block_dets, *, repeated_message=False):
                 well. They may also indicate the code needs to be reworked.
                 """)
         )
+    else:
+        idiomatic = ''
+
     message = {
-        conf.BRIEF: brief_msg,
-        conf.MAIN: main_msg,
+        conf.BRIEF: title + sometimes_ok,
+        conf.MAIN: title + sometimes_ok + idiomatic,
     }
     return message
