@@ -6,7 +6,7 @@ from ..utils import layout_comment as layout
 ASSIGN_FUNC_NAME_XPATH = 'descendant-or-self::Assign/value/Call/func/Name'
 
 @filt_block_advisor(xpath=ASSIGN_FUNC_NAME_XPATH)
-def set_overview(block_dets, *, repeated_message=False):
+def set_overview(block_dets, *, repeat=False):
     """
     Look for sets and provide general advice on using them and finding out more.
     """
@@ -27,36 +27,28 @@ def set_overview(block_dets, *, repeated_message=False):
         name_sets.append((name, my_set))
     if not has_set:
         return None
-    brief_msg = ''
-    no_duplicates_demo = ''
+
+    title = layout("""\
+
+        ### Set details
+
+        """)
+    summary_bits = []
     for name, my_set in name_sets:
         empty_set = len(my_set) == 0
-        if not empty_set:
+        if empty_set:
+            summary_bits.append(layout(f"""\
+                `{name}` is an empty set.
+                """))
+        else:
             members = str(sorted(my_set)).strip('[').strip(']')
-            brief_msg += layout(f"""\
+            summary_bits.append(layout(f"""\
                 `{name}` is a set with {utils.int2nice(len(my_set))} members:
                 {members}
-                """)
-            set_item = list(my_set)[0]
-            if not no_duplicates_demo and not repeated_message:  ## only want one demo even if multiple sets defined in block
-                no_duplicates_demo = (
-                    layout(f"""\
-
-                    For example:
-
-                    """)
-                    +
-                    layout(f"""\
-                        {name}.add({set_item})
-                        ## >>> {my_set}
-                        """, is_code=True)
-                )
-        else:
-            brief_msg += layout(f"""\
-                `{name}` is an empty set.
-                """)
-    if not repeated_message:
-        brief_msg += (
+                """))
+    summary = ''.join(summary_bits)
+    if not repeat:
+        sets_rock = (
             layout("""\
 
                 Python sets are brilliant. There are often cases in programming
@@ -76,18 +68,31 @@ def set_overview(block_dets, *, repeated_message=False):
                 ## >>> {'Noor', 'Hyeji', 'Avi'}
                 """, is_code=True)
         )
-    if repeated_message:
-        main_msg = brief_msg
-        extra_msg = ''
-    else:
-        main_msg = (
-            brief_msg
-            +
+        no_duplicates_demo = ''
+        for name, my_set in name_sets:
+            empty_set = len(my_set) == 0
+            if not empty_set:
+                members = str(sorted(my_set)).strip('[').strip(']')
+                existing_set_item = list(my_set)[0]
+                no_duplicates_demo = (
+                    layout(f"""\
+
+                    For example:
+
+                    """)
+                    +
+                    layout(f"""\
+                        {name}.add({existing_set_item})
+                        ## >>> {my_set}
+                        """, is_code=True)
+                )
+                break
+        set_dets = (
             layout(f"""\
 
-                Being a set, all members are unique by definition
-                so if you add something to a set that is already a member
-                the set doesn't change.
+                Being a set, all members are unique by definition so if you add
+                something to a set that is already a member the set doesn't
+                change.
                 """)
             +
             no_duplicates_demo
@@ -111,16 +116,16 @@ def set_overview(block_dets, *, repeated_message=False):
                 ## >>> {1, 2, 3, 4}
                 """, is_code=True)
         )
-        extra_msg = (
+        set_extras = (
             layout("""\
                 Set operations can be expressed with operators such as
-                '-' (minus) or with methods such as .difference().
+                `-` (minus) or with methods such as .difference().
 
                 Sets are well explained in the official documentation so it will
                 suffice to show a simple example.
 
-                Note - the operator corresponding to the .union() method is the pipe
-                '|' not '+'.
+                Note - the operator corresponding to the `.union()` method is
+                the pipe `|` not `+`.
                 """)
             +
             layout("""\
@@ -131,9 +136,14 @@ def set_overview(block_dets, *, repeated_message=False):
                 ## >>> {'Grzegorz', 'Giles', 'Grant', 'Aravind', 'Charlotte'}
                 """, is_code=True)
         )
+    else:
+        sets_rock = ''
+        set_dets = ''
+        set_extras = ''
+
     message = {
-        conf.BRIEF: brief_msg,
-        conf.MAIN: main_msg,
-        conf.EXTRA: extra_msg,
+        conf.BRIEF: title + summary + sets_rock,
+        conf.MAIN: title + summary + sets_rock + set_dets,
+        conf.EXTRA: set_extras,
     }
     return message
