@@ -1,6 +1,5 @@
 import datetime
 import logging
-from pathlib import Path
 
 t = True
 f = False
@@ -27,20 +26,9 @@ else:
 ## When testing user-supplied snippets watch out for the BOM MS inserts via Notepad. AST chokes on it.
 
 TEST_SNIPPET = """\
-if word is not None:
-    if len(word) > 20:
-        pass
-
-if word is not None:
-    if len(word) > 20:
-        pass
-    else:
-        pass
-
-if word is not None:
-    if len(word) > 20:
-        pass
-    pass
+pets = 'seagull'
+home = 'super volcano'
+appliance = 'garbage disposal'
 """
 
 DEMO_SNIPPET = """\
@@ -71,7 +59,8 @@ def powerMe(num, *, power=2):
 coord = ('lat', 'lon')
 latitude = coord[0]
 longitude = coord[1]
-x, y = coord
+demo = (1, 2, 3, 4)
+x, yy, zz, aaa = demo
 people = set(['Sam', 'Avi', 'Terri', 'Noor'])
 no_email = set(['Sam', 'Terri'])
 people2email = people - no_email
@@ -170,7 +159,7 @@ PY3_6 = '3.6'
 PY3_7 = '3.7'
 PY3_8 = '3.8'
 
-AST_OUTPUT_XML = Path(__file__).parent / 'ast_output.xml'
+AST_OUTPUT_XML_FNAME = 'ast_output.xml'
 
 PYTHON_CODE_START = '__python_code_start__'
 PYTHON_CODE_END = '__python_code_end__'
@@ -223,19 +212,27 @@ MAX_BRIEF_FUNC_ARGS = 6
 MIN_BRIEF_DOCSTRING = 3
 MIN_BRIEF_NAME = 3
 MAX_BRIEF_NESTED_BLOCK = 20
+MIN4ANY_OR_ALL = 3
 
 FUNCTION_LBL = 'function'
 METHOD_LBL = 'method'
 
+EMAIL2USE = 'superhelp@p-s.co.nz'
+
 NO_ADVICE_MESSAGE = ("No advice to give - looks fine :-). But if you think "
-    "there should have been some advice given, contact grant@p-s.co.nz with "
-    "the subject line 'Advice' and explain. Please include a snippet to test as"
-    " well.")
-MISSING_ADVICE_MESSAGE = ("If there was some advice you think should have been "
-    "given that wasn't, contact grant@p-s.co.nz with the subject line 'Advice' "
-    "and explain. Please include a snippet to test as well.")
+    f"there should have been some advice given, contact {EMAIL2USE} "
+    "with the subject line 'Advice' and explain. Please include a snippet to "
+    "test as well.")
+MISSING_ADVICE_MESSAGE = ("If there was some advice you think should have "
+    f"been given that wasn't, contact {EMAIL2USE} with the subject line "
+    "'Advice' and explain. Please include a snippet to test as well.")
 SYSTEM_MESSAGE = 'System message'
 
+XKCD_WARNING_WORDS = ['supervolcano', 'seagull', 'garbage disposal']
+
+VERBOSE_FLAG = 'VERBOSE'
+INLINE_RE_VERBOSE_FLAG = '(?x)'
+
 LINE_FEED = '&#10;'
 
 ## scraped from https://docs.python.org/3/py-modindex.html 2020-04-02
