@@ -83,8 +83,17 @@ astpath.asts.convert_to_xml = convert_to_xml
 
 ## importing from superhelp only works properly after I've installed superhelp as a pip package (albeit as a link to this code using python3 -m pip install --user -e <path_to_proj_folder>)
 ## Using this as a library etc works with . instead of superhelp but I want to be be able to run the helper module from within my IDE
-from superhelp import advisors, ast_funcs, conf  # @UnresolvedImport
-from superhelp.utils import layout_comment  # @UnresolvedImport
+
+try:
+    from . import advisors, ast_funcs, conf  # @UnresolvedImport @UnusedImport
+    from ..utils import get_docstring_start, layout_comment as layout, make_tmp_file  # @UnresolvedImport @UnusedImport
+except (ImportError, ValueError):
+    from pathlib import Path
+    import sys
+    parent = Path.cwd().parent
+    sys.path.insert(0, parent)
+    from superhelp import advisors, ast_funcs, conf  # @Reimport
+    from superhelp.utils import get_docstring_start, layout_comment as layout, make_tmp_file  # @Reimport
 
 BlockDets = namedtuple(
     'BlockDets', 'element, pre_block_code_str, block_code_str, first_line_no')
@@ -95,10 +104,11 @@ MessageDets = namedtuple('MessageDets',
     'code_str, message, first_line_no, warning, source')
 MessageDets.__doc__ += (
     "All the bits and pieces that might be needed to craft a message")
+MessageDets.code_str.__doc__ = ("The block of code the message relates to")
 MessageDets.source.__doc__ = ("A unique identifier of the source of message "
     "- useful for auditing / testing")
 
-def get_tree(snippet):
+def _get_tree(snippet):
     try:
         tree = ast.parse(snippet)
     except SyntaxError as e:
@@ -106,7 +116,7 @@ def get_tree(snippet):
             f"Oops - something seems broken in the snippet - details: {e}")
     return tree
 
-def get_blocks_dets(xml, snippet_lines):
+def get_blocks_dets(snippet, snippet_block_els):
     """
     Returning a list of all the details needed to process a line
     (namely BlockDets named tuples)
@@ -116,18 +126,18 @@ def get_blocks_dets(xml, snippet_lines):
     :return: list of BlockDets named tuples
     :rtype: list
     """
+    snippet_lines = snippet.split('\n')
     blocks_dets = []
-    all_elements = xml.xpath('body')[0].getchildren()  ## [0] because there is only one body under root
-    for element in all_elements:
+    for snippet_block_el in snippet_block_els:
         first_line_no, last_line_no, _el_lines_n = ast_funcs.get_el_lines_dets(
-            element)
+            snippet_block_el)
         block_code_str = (
             '\n'.join(snippet_lines[first_line_no - 1: last_line_no]).strip())
         pre_block_code_str = (
             '\n'.join(snippet_lines[0: first_line_no - 1]).strip()
             + '\n')
         blocks_dets.append(BlockDets(
-            element, pre_block_code_str, block_code_str, first_line_no))
+            snippet_block_el, pre_block_code_str, block_code_str, first_line_no))
     return blocks_dets
 
 def complete_message(message, *, source):
@@ -156,7 +166,7 @@ def complete_message(message, *, source):
     return message
 
 def get_message_dets_from_input(advisor_dets, *,
-        advisor_input, code_str, first_line_no, repeated_message):
+        advisor_input, code_str, first_line_no, repeat):
     name = advisor_dets.advisor_name
     docstring = advisor_dets.advisor.__doc__
     if not docstring:
@@ -164,24 +174,25 @@ def get_message_dets_from_input(advisor_dets, *,
     try:
         try:
             message = advisor_dets.advisor(advisor_input,
-                repeated_message=repeated_message)
+                repeat=repeat)
         except TypeError as e:
-            if "unexpected keyword argument 'repeated_message'" in str(e):
+            if "unexpected keyword argument 'repeat'" in str(e):
                 message = advisor_dets.advisor(advisor_input)
             else:
                 raise
     except Exception as e:
         message = {
             conf.BRIEF: (
-                layout_comment(f"""\
+                layout(f"""\
+
                     ### Advisor "`{name}`" unable to run
 
                     Advisor {name} unable to run. Advisor description:
                     """)
                 +  ## show first line of docstring (subsequent lines might have more technical, internally-oriented comments)
-                layout_comment(docstring.lstrip('\n').split('\n\n')[0] + '\n')
+                layout(get_docstring_start(docstring) + '\n')
                 +
-                layout_comment(str(e))
+                layout(str(e))
             )
         }
         source = conf.SYSTEM_MESSAGE
@@ -193,7 +204,7 @@ def get_message_dets_from_input(advisor_dets, *,
             return None
     message = complete_message(message, source=source)
     message_dets = MessageDets(
-        code_str, message, first_line_no, warning, source=name)
+        code_str, message, first_line_no, warning, source=source)
     return message_dets
 
 def _get_ancestor_block_element(element):
@@ -251,15 +262,15 @@ def get_block_level_messages_dets(blocks_dets, xml):
                 f"{len(blocks_dets2use)} matching blocks")
         else:  ## no filtering by element type so process all blocks
             blocks_dets2use = blocks_dets
-        repeated_message = False
+        repeat = False
         for block_dets in blocks_dets2use:
             message_dets = get_message_dets_from_input(advisor_dets,
                 advisor_input=block_dets, code_str=block_dets.block_code_str,
                 first_line_no=block_dets.first_line_no,
-                repeated_message=repeated_message)
+                repeat=repeat)
             if message_dets:
                 messages_dets.append(message_dets)
-                repeated_message = True
+                repeat = True
     return messages_dets
 
 def get_overall_snippet_messages_dets(snippet, blocks_dets):
@@ -271,38 +282,26 @@ def get_overall_snippet_messages_dets(snippet, blocks_dets):
     for advisor_dets in advisors.SNIPPET_ADVISORS:
         message_dets = get_message_dets_from_input(advisor_dets,
             advisor_input=blocks_dets, code_str=snippet, first_line_no=None,
-            repeated_message=False)
+            repeat=False)
         if message_dets:
             messages_dets.append(message_dets)
     return messages_dets
 
-def get_separated_messages_dets(snippet):
+def get_separated_messages_dets(snippet, snippet_block_els, xml):
     """
     Break snippet up into syntactical parts and blocks of code. Apply advisor
     functions and get message details. Split into overall messages and block-
     specific messages.
 
     :param str snippet: code snippet
+    :param list snippet_block_els: list of block elements for snippet
+    :param xml xml: snippet code as xml object
     :return: a tuple of two MessageDets lists
      (overall_snippet_messages_dets, block_level_messages_dets)
      or None if no messages
     :rtype: tuple (or None)
     """
-    tree = get_tree(snippet)
-    xml = astpath.asts.convert_to_xml(tree)
-    if conf.RECORD_AST:
-        xml.getroottree().write(str(conf.AST_OUTPUT_XML), pretty_print=True)
-        logging.info("""\
-
-
-
-        Updating AST
-
-
-
-        """)
-    snippet_lines = snippet.split('\n')
-    blocks_dets = get_blocks_dets(xml, snippet_lines)
+    blocks_dets = get_blocks_dets(snippet, snippet_block_els)
     overall_snippet_messages_dets = get_overall_snippet_messages_dets(
         snippet, blocks_dets)
     block_level_messages_dets = get_block_level_messages_dets(blocks_dets, xml)
@@ -321,25 +320,72 @@ def get_separated_messages_dets(snippet):
                 first_line_no=None, warning=False, source=conf.SYSTEM_MESSAGE)]
     return overall_snippet_messages_dets, block_level_messages_dets
 
+def store_ast_output(xml):
+    _tmp_ast_fh, tmp_ast_output_xml_fpath = make_tmp_file(
+        conf.AST_OUTPUT_XML_FNAME, mode='w')
+    xml.getroottree().write(str(tmp_ast_output_xml_fpath), pretty_print=True)
+    logging.info("\n\n\n\n\nUpdating AST\n\n\n\n\n")
+
+def get_snippet_dets(snippet):
+    tree = _get_tree(snippet)
+    xml = astpath.asts.convert_to_xml(tree)
+    if conf.RECORD_AST:
+        store_ast_output(xml)
+    snippet_block_els = xml.xpath('body')[0].getchildren()  ## [0] because there is only one body under root
+    multi_block_snippet = len(snippet_block_els) > 1
+    snippet_messages_dets = get_separated_messages_dets(
+        snippet, snippet_block_els, xml)
+    return snippet_messages_dets, multi_block_snippet
+
+def get_system_messages_dets(snippet, brief_message, *, warning=True):
+    """
+    Even though only one message is needed, supplying the details in the
+    standard format the displayers expect means they can operate in their usual
+    messages_dets consuming ways :-).
+    """
+    message = {
+        conf.BRIEF: brief_message,
+    }
+    message = complete_message(message, source=conf.SYSTEM_MESSAGE)
+    overall_messages_dets = [
+        MessageDets(snippet, message,
+            first_line_no=None, warning=warning, source=conf.SYSTEM_MESSAGE)]
+    block_messages_dets = []
+    messages_dets = (overall_messages_dets, block_messages_dets)
+    return messages_dets
+
 def get_error_messages_dets(e, snippet):
     """
     If unable to produce any messages, supply the problem in the form of
     standard messages_dets so the displayers can operate in their usual
     messages_dets consuming ways :-).
     """
-    message = {
-        conf.BRIEF: layout_comment(f"""\
-            ### No advice sorry :-(
+    brief_message = layout(f"""\
+        ### No advice sorry :-(
 
-            Unable to provide advice - some sort of problem.
+        Unable to provide advice - some sort of problem.
 
-            Details: {e}
-            """),
-    }
-    message = complete_message(message, source=conf.SYSTEM_MESSAGE)
-    overall_messages_dets = [
-        MessageDets(snippet, message,
-            first_line_no=None, warning=True, source=conf.SYSTEM_MESSAGE)]
-    block_messages_dets = []
-    messages_dets = (overall_messages_dets, block_messages_dets)
-    return messages_dets
+        Details: {e}
+        """)
+    return get_system_messages_dets(snippet, brief_message)
+
+def get_community_message(snippet):
+    brief_message = layout("""\
+
+        ### Join in!
+
+        Python has always had a great community. Learn more at
+        <https://www.python.org/community/>. Better still - get involved :-)
+
+        """)
+    return get_system_messages_dets(snippet, brief_message)
+
+def get_xkcd_warning(snippet):
+    brief_message = layout("""\
+
+        ### According to XKCD this code could be *very* dangerous
+
+        See <https://xkcd.com/2261/>
+
+        """)
+    return get_system_messages_dets(snippet, brief_message)
